@@ -4,8 +4,12 @@ from wheel.bdist_wheel import bdist_wheel
 
 custom_extension = Extension(
     'tsp_algorithms.ctsp',
-    sources=['tsp_algorithms/lib/tsp.c', 'tsp_algorithms/lib/nearest_neighbors.c'],
-    define_macros=[("Py_LIMITED_API", "0x03060000")],
+    sources=[
+        'tsp_algorithms/lib/tsp.c',
+        'tsp_algorithms/lib/algorithms.c',
+        'tsp_algorithms/lib/metrics.c',
+    ],
+    define_macros=[('Py_LIMITED_API', '0x03060000'), ('PY_SSIZE_T_CLEAN',)],
     py_limited_api=True,
 )
 
@@ -14,9 +18,9 @@ class bdist_wheel_abi3(bdist_wheel):
     def get_tag(self):
         python, abi, plat = super().get_tag()
 
-        if python.startswith("cp"):
+        if python.startswith('cp'):
             # on CPython, our wheels are abi3 and compatible back to 3.8
-            return "cp38", "abi3", plat
+            return 'cp38', 'abi3', plat
 
         return python, abi, plat
 
@@ -28,7 +32,7 @@ def build(setup_kwargs):
     setup_kwargs.update(
         {
                 # declare the extension so that setuptools will compile it
-                "ext_modules": [custom_extension],
-                "cmdclass": {"bdist_wheel": bdist_wheel_abi3},
+                'ext_modules': [custom_extension],
+                'cmdclass': {'bdist_wheel': bdist_wheel_abi3},
         }
     )
\ No newline at end of file
